;; Generated package description from pyim-basedict.el  -*- no-byte-compile: t -*-
(define-package "pyim-basedict" "0.5.0" "The default pinyin dict of pyim" 'nil :keywords '("convenience" "chinese" "pinyin" "input-method" "complete") :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :url "https://github.com/tumashu/pyim-basedict")
